@@ -1,20 +1,3 @@
-#' The aim of TCGAbiolinks is : i) facilitate the TCGA open-access data retrieval,
-#' ii) prepare the data using the appropriate pre-processing strategies,
-#'  iii) provide the means to carry out different standard analyses and
-#'  iv) allow the user to download a specific version of the data and thus to easily reproduce earlier research results.
-#'   In more detail, the package provides multiple methods for analysis
-#' (e.g., differential expression analysis, identifying differentially methylated regions)
-#' and methods for visualization (e.g., survival plots, volcano plots, starburst plots) in order to easily develop complete analysis pipelines.
-#'
-#' The functions you're likely to need from \pkg{TCGAbiolinks} is
-#' \code{\link{GDCdownload}}, \code{\link{GDCquery}}.
-#' Otherwise refer to the vignettes to see
-#' how to format the documentation.
-#'
-#' @docType package
-#' @name TCGAbiolinks
-NULL
-
 #' Clinical data TCGA BRCA
 #' @docType data
 #' @keywords internal
@@ -68,8 +51,9 @@ NULL
 
 #' geneInfoHT for normalization of HTseq data
 #' @description
-#' Code to generate the data
-#' ```{R, eval = F}
+#' Code to generate the data in examples
+#' @examples
+#' \dontrun{
 #' library(EDASeq)
 #' library(biomaRt)
 #' #get ensembl gene IDs for hg38
@@ -100,7 +84,7 @@ NULL
 #' )
 #' #Save final table
 #' save(geneInfoHT, file = "data/geneInfoHT.rda")
-#' ```
+#' }
 #' @docType data
 #' @keywords internal
 #' @name geneInfoHT
