@@ -139,7 +139,7 @@ GDCprepare <- function(
     }
 
     cases <- ifelse(
-        grepl("TCGA|TARGET|CGCI-HTMCP-CC|CPTAC-2",query$results[[1]]$project %>% unlist()),
+        grepl("TCGA|TARGET|CGCI-HTMCP-CC|CPTAC-2|BEATAML1.0-COHORT",query$results[[1]]$project %>% unlist()),
         query$results[[1]]$cases,
         query$results[[1]]$sample.submitter_id
     )
@@ -503,6 +503,10 @@ readSimpleNucleotideVariationMaf <- function(files){
                     TRANSCRIPT_STRAND = col_integer(),
                     PICK = col_integer(),
                     TSL = col_integer(),
+                    Allele =  col_character(),
+                    Tumor_Seq_Allele1 =  col_character(),
+                    Reference_Allele = col_character(),
+                    Tumor_Seq_Allele2 = col_character(),
                     DISTANCE = col_integer()
                 ))
 
@@ -838,12 +842,38 @@ readDNAmethylation <- function(
 
         # Just check if the data is in the same order, since we will not merge
         # the data frames to save memory
-        stopifnot(all(unlist(x %>% map(function(y){all(y[,1]$V1 ==  x[[1]][,1]$V1)}) )))
+        # C3N-01362-01 has less probes than C3L-00913-03 due to version of the array
+        # CPTAC cohort: 55 samples with EPIC v1 and 1808  with EPIC V2
+        # EPIC v1 has less probes than EPIC V2
 
-        df <- x %>%  map_df(2)
-        colnames(df) <- x %>%  map_chr(.f = function(y) colnames(y)[2])
+        # In case we have multiple versions of the array we will
+        # 1. Check the names of all of the same nrow
+        # 2. Bind the ones with same nrow
+        # 3. Full join the two objects
+        nrow_vec <- purrr::map_int(x,nrow) # number of rows each file
+        nrow_vec_numbers <- nrow_vec %>% unique # unique number of rows
+
+        for(nb_rows in nrow_vec_numbers){
+            aux <- x[which(nrow_vec == nb_rows)]
+            stopifnot(all(unlist(aux %>% map(function(y){all(y[,1]$V1 ==  aux[[1]][,1]$V1)}) )))
+        }
+
+        df <- map(nrow_vec_numbers,.f = function(nb_rows){
+            file_equal_probes <- x[which(nrow_vec == nb_rows)]
+            df <- file_equal_probes %>% map_df(2)
+            colnames(df) <- file_equal_probes %>% map_chr(.f = function(y) colnames(y)[2])
+            df$V1 <- file_equal_probes[[1]]$V1
+            if (any(duplicated(colnames(df)))){
+                message("oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo")
+                message("Duplicated samples names were found. Adding _rep suffix to name")
+                message("oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo")
+            }
+            colnames(df)[duplicated(colnames(df))] <- paste0(colnames(df)[duplicated(colnames(df))],"_rep")
+            df
+        }) %>% purrr::reduce(dplyr::full_join,by = "V1") %>% as.data.frame()
+        rownames(df) <- df$V1
+        df$V1 <- NULL
         df <- data.matrix(df)
-        rownames(df) <- setDF(x[[1]])[,1,drop = T]
 
         if (summarizedExperiment) {
 
@@ -915,7 +945,9 @@ readDNAmethylation <- function(
 }
 
 # Barcode example MMRF_1358_1_BM_CD138pos_T1_TSMRU_L02337
-colDataPrepareMMRF <- function(barcode){
+colDataPrepareMMRF <- function(
+        barcode
+){
     DataFrame(
         barcode = barcode,
         sample = barcode,
@@ -923,8 +955,9 @@ colDataPrepareMMRF <- function(barcode){
     )
 }
 
-colDataPrepareTARGET <- function(barcode){
-
+colDataPrepareTARGET <- function(
+        barcode
+){
 
     message("Adding description to TARGET samples")
     tissue.code <- c(
@@ -1251,6 +1284,14 @@ colDataPrepare <- function(barcode){
 
     if(any(ret$project_id %in% c("CMI-MBC","TARGET-NBL"),na.rm = T)) {
         idx <- match(barcode,ret$bcr_patient_barcode)
+        # Workaround for the moment, still need to understand the barcode (cases)
+        # is TARGET-30-PAPKXS-01A-01D and not TARGET-30-PAPKXS-01A
+        if(all(is.na(idx))){
+            idx <- match(
+                stringr::str_sub(barcode,1,min(stringr::str_length(ret$bcr_patient_barcode))),
+                ret$bcr_patient_barcode
+            )
+        }
     }
 
 
