@@ -17,16 +17,16 @@ DT::datatable(
     rownames = FALSE
 )
 
-## ---- eval = TRUE-------------------------------------------------------------
-lgg_gbm_subtype <- TCGAquery_subtype(tumor = "lgg")
+## ----eval = TRUE--------------------------------------------------------------
+lgg.gbm.subtype <- TCGAquery_subtype(tumor = "lgg")
 
-## ---- eval = TRUE, echo = FALSE-----------------------------------------------
+## ----eval = TRUE, echo = FALSE------------------------------------------------
 datatable(
-  lgg_gbm_subtype[1:10,],
-  caption = "Table with LGG molecular subtypes from TCGAquery_subtype",
-  filter = 'top',
-  options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
-  rownames = FALSE
+    lgg.gbm.subtype[1:10,],
+    caption = "Table with LGG molecular subtypes from TCGAquery_subtype",
+    filter = 'top',
+    options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
+    rownames = FALSE
 )
 
 ## ----sessionInfo--------------------------------------------------------------
