@@ -28,12 +28,14 @@ test_that("TCGAanalyze_DMC ask for the missing parameters", {
     nrows <- 2
     ncols <- 20
     counts <- matrix(c(rep(0.9, 20), rep(0.1, 20)), nrows)
-    rowRanges <- GenomicRanges::GRanges((rep("chr1", 2)),
-                                        IRanges::IRanges(c(2000, 2000), width =
-                                                             100),
-                                        strand = c("+", "-"),
-                                        feature_id = sprintf("ID%03d", 1:2)
+    rowRanges <- GenomicRanges::GRanges(
+        (rep("chr1", 2)),
+        IRanges::IRanges(c(2000, 2000), width =
+                             100),
+        strand = c("+", "-"),
+        feature_id = sprintf("ID%03d", 1:2)
     )
+
     colData <-
         S4Vectors::DataFrame(
             Treatment = rep(c("ChIP", "Input"), 5),
@@ -42,11 +44,13 @@ test_that("TCGAanalyze_DMC ask for the missing parameters", {
                 "group1", "group2", "group3", "group4"
             ), c(5, 5, 5, 5))
         )
+
     data <- SummarizedExperiment::SummarizedExperiment(
         assays = S4Vectors::SimpleList(counts = counts),
         rowRanges = rowRanges,
         colData = colData
     )
+
     expect_null(TCGAanalyze_DMC(data, p.cut = 0.85))
     expect_message(TCGAanalyze_DMC(data, p.cut = 0.85),
                    "Please, set the groupCol parameter")
@@ -62,27 +66,27 @@ test_that("TCGAanalyze_DMC is handling NAs correctly", {
     ncols <- 20
     counts <- matrix(c(rep(0.9, 20), rep(0.1, 20)), nrows)
     counts[1, 1] <- NA
-    rowRanges <- GenomicRanges::GRanges((rep("chr1", 2)),
-                                        IRanges::IRanges(c(2000, 2000), width =
-                                                             100),
-                                        strand = c("+", "-"),
-                                        feature_id = sprintf("ID%03d", 1:2)
+    rowRanges <- GenomicRanges::GRanges(
+        (rep("chr1", 2)),
+        IRanges::IRanges(c(2000, 2000), width = 100),
+        strand = c("+", "-"),
+        feature_id = sprintf("ID%03d", 1:2)
     )
+
     colData <-
         S4Vectors::DataFrame(
             Treatment = rep(c("ChIP", "Input"), 5),
             row.names = LETTERS[1:20],
             group = rep(c("group1", "group2"), c(10, 10))
         )
+
     data <- SummarizedExperiment::SummarizedExperiment(
         assays = S4Vectors::SimpleList(counts = counts),
         rowRanges = rowRanges,
         colData = colData
     )
-    SummarizedExperiment::colData(data)$group <-
-        c(rep("group1", 10),  rep("group2", 10))
-    hypo.hyper <-
-        TCGAanalyze_DMC(data, p.cut = 0.85, "group", "group1", "group2")
+    SummarizedExperiment::colData(data)$group <- c(rep("group1", 10),  rep("group2", 10))
+    hypo.hyper <- TCGAanalyze_DMC(data, p.cut = 0.85, "group", "group1", "group2")
     result <- hypo.hyper[1,]
     expect_equal(result$mean.group1, 0.9)
     expect_equal(result$mean.group2, 0.1)
@@ -168,7 +172,7 @@ test_that(
                 method = "glmLRT"
             )
         })
-        expect_equal(dataDEGs$logFC, -1 * dataDEGs.inv$logFC)
+        expect_equal(dataDEGs$logFC, -1 * dataDEGs.inv[rownames(dataDEGs),]$logFC)
         expect_equal(dataDEGs.inv["CLDN6|9074", ]$logFC > 0, (log2FC.inv > 0)[[1]])
 
     }
@@ -177,13 +181,16 @@ test_that(
 test_that("Results from TCGAanalyze_DMC are correct", {
     nrows <- 2
     ncols <- 20
-    counts <- matrix(c(rep(0.9, 20), rep(0.1, 20)), nrows,
-                     dimnames = list(paste0("cg", 1:2), LETTERS[1:20]))
-    rowRanges <- GenomicRanges::GRanges((rep("chr1", 2)),
-                                        IRanges::IRanges(c(2000, 2000), width =
-                                                             100),
-                                        strand = c("+", "-"),
-                                        feature_id = sprintf("ID%03d", 1:2)
+    counts <- matrix(
+        c(rep(0.9, 20), rep(0.1, 20)), nrows,
+        dimnames = list(paste0("cg", 1:2), LETTERS[1:20])
+    )
+
+    rowRanges <- GenomicRanges::GRanges(
+        (rep("chr1", 2)),
+        IRanges::IRanges(c(2000, 2000), width = 100),
+        strand = c("+", "-"),
+        feature_id = sprintf("ID%03d", 1:2)
     )
     colData <-
         S4Vectors::DataFrame(
@@ -191,11 +198,13 @@ test_that("Results from TCGAanalyze_DMC are correct", {
             row.names = LETTERS[1:20],
             group = rep(c("group1", "group2"), c(10, 10))
         )
+
     data <- SummarizedExperiment::SummarizedExperiment(
         assays = S4Vectors::SimpleList(counts = counts),
         rowRanges = rowRanges,
         colData = colData
     )
+
     SummarizedExperiment::colData(data)$group <-
         c(rep("group1", 10),  rep("group2", 10))
     hypo.hyper <- TCGAanalyze_DMC(data, p.cut = 0.85, "group", "group1", "group2")
